AmberPrepParser
======================

.. currentmodule:: biskit

.. autoclass:: AmberPrepParser
   :members:
   :show-inheritance:
   :special-members: __init__

   

   
   .. rubric:: Methods Overview

   .. autosummary::
      :nosignatures:
   
   
      ~AmberPrepParser.__init__
      ~AmberPrepParser.atomLines
      ~AmberPrepParser.createResidue
      ~AmberPrepParser.parseCharges
      ~AmberPrepParser.parseResidue
      ~AmberPrepParser.residueBlocks
      ~AmberPrepParser.residueDict
      ~AmberPrepParser.residueTypes
   
   

   
   
   .. rubric:: Attributes Overview

   .. autosummary::
   
      ~AmberPrepParser.F_DEFAULT
   
   

   
   
   .. raw:: html
      
      <hr>
      <h2>AmberPrepParser Method & Attribute Details</h2>

   
   